summaryrefslogtreecommitdiff
path: root/mysys/mf_soundex.c
diff options
context:
space:
mode:
authorbar@bar.mysql.r18.ru <>2002-08-15 16:42:54 +0500
committerbar@bar.mysql.r18.ru <>2002-08-15 16:42:54 +0500
commit34d4c4f46213c1b71b650581736b812444646b1d (patch)
tree0771a890e5d8ed36e182ce6069988f32b9db0bc7 /mysys/mf_soundex.c
parente353a35f6466e7fba7140dd64c86b88a595b762a (diff)
downloadmariadb-git-34d4c4f46213c1b71b650581736b812444646b1d.tar.gz
Some speed improvements
Diffstat (limited to 'mysys/mf_soundex.c')
-rw-r--r--mysys/mf_soundex.c3
1 files changed, 2 insertions, 1 deletions
diff --git a/mysys/mf_soundex.c b/mysys/mf_soundex.c
index 8ecd95137b0..459e304dfd7 100644
--- a/mysys/mf_soundex.c
+++ b/mysys/mf_soundex.c
@@ -44,13 +44,14 @@ void soundex(CHARSET_INFO * cs,register my_string out_pntr, my_string in_pntr,
{
char ch,last_ch;
reg3 my_string end;
+ register uchar *map=cs->to_upper;
if (remove_garbage)
{
while (*in_pntr && my_isspace(cs,*in_pntr)) /* Skipp pre-space */
in_pntr++;
}
*out_pntr++ = my_toupper(cs,*in_pntr);/* Copy first letter */
last_ch = get_scode(cs,&in_pntr,0); /* code of the first letter */
/* for the first 'double-letter */
/* check. */
@@ -44,13 +44,14 @@ void soundex(CHARSET_INFO * cs,register my_string out_pntr, my_string in_pntr,
in_pntr++;
}
- *out_pntr++ = my_toupper(cs,*in_pntr);/* Copy first letter */
+ *out_pntr++ = map[(uchar)*in_pntr]; /* Copy first letter */
last_ch = get_scode(cs,&in_pntr,0); /* code of the first letter */
/* for the first 'double-letter */